---
name: Documentation improvement
about: Is the documentation of something missing, unclear, or lacking? This is the place.
title: ''
labels: 'documentation'
assignees: ''

---
<!--
For the Documentation request, please include the following:
------------------------
What would you like changed/added and why?
Do you have any suggestions for the new documents?
-->
